@@ -389,40 +389,6 @@ audio_view_media_get_metadata (GstMediaInfoStream *info)
 	if (artist)
 		return g_strdup_printf ("%s%s", _("Artist: "), artist);
 	return g_strdup_printf ("%s%s", _("Title: "), title);
-
-#if 0
-FIXME: GstPropsEntry is gone, get the right way of tagging extraction done here
-	while (p)
-	{
-		GstPropsEntry *entry = (GstPropsEntry *) p->data;
-		const gchar *name;
-		const gchar *val;
-
-		name = gst_props_entry_get_name (entry);
-		if (g_ascii_strncasecmp (name, "artist", 6) == 0)
-			artist = g_list_append (artist, entry);
-		if (g_ascii_strncasecmp (name, "title", 6) == 0)
-			title = g_list_append (title, entry);
-		p = g_list_next (p);
-	}
-
-        /* check if we have something */
-        if (!artist && !title) return NULL; //g_strdup ("");
-	/* now construct a string out of it */
-	artists = audio_view_props_to_string (artist, _("Artist: "));
-	titles = audio_view_props_to_string (title, _("Title: "));
-	if (artists && titles)
-	{
-		metadata = g_strconcat (artists, titles, NULL);
-		g_free (artists);
-		g_free (titles);
-	}
-	else if (artists) metadata = artists;
-	else metadata = titles;
-
-	/* we chomp because it looks better in the list view */
-	return g_strchomp (metadata);
-#endif
 }
 
 /* set next track to play
@@ -464,12 +430,11 @@ audio_view_play_next (AudioView *view)
 				    -1);
 		NM_DEBUG("play_next: track to play is %s\n", info->path);
 
-	if (!audio_view_is_playable (info->path))
-        {
-		NM_DEBUG("play_next: %s is not playable\n", info->path);
-		return FALSE;
-	}
-	audio_view_set_playing (view, info, path);
+		if (!audio_view_is_playable (info->path))
+		{
+			NM_DEBUG("play_next: %s is not playable\n", info->path);
+			return FALSE;
+		}
 		audio_view_set_playing (view, info, path);
 		gtk_tree_path_free (path);
 		return TRUE;
